ipecharts.option package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ipecharts.option.datazoomitems
   ipecharts.option.mediaitems
   ipecharts.option.seriesitems
   ipecharts.option.visualmapitems

Submodules
----------

ipecharts.option.angleaxis module
---------------------------------

.. automodule:: ipecharts.option.angleaxis
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.aria module
----------------------------

.. automodule:: ipecharts.option.aria
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.axispointer module
-----------------------------------

.. automodule:: ipecharts.option.axispointer
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.basewidget module
----------------------------------

.. automodule:: ipecharts.option.basewidget
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.brush module
-----------------------------

.. automodule:: ipecharts.option.brush
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.calendar module
--------------------------------

.. automodule:: ipecharts.option.calendar
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.dataset module
-------------------------------

.. automodule:: ipecharts.option.dataset
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.datazoom module
--------------------------------

.. automodule:: ipecharts.option.datazoom
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.geo module
---------------------------

.. automodule:: ipecharts.option.geo
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.geo3d module
-----------------------------

.. automodule:: ipecharts.option.geo3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.globe module
-----------------------------

.. automodule:: ipecharts.option.globe
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.graphic module
-------------------------------

.. automodule:: ipecharts.option.graphic
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.grid module
----------------------------

.. automodule:: ipecharts.option.grid
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.grid3d module
------------------------------

.. automodule:: ipecharts.option.grid3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.legend module
------------------------------

.. automodule:: ipecharts.option.legend
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.mapbox3d module
--------------------------------

.. automodule:: ipecharts.option.mapbox3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.media module
-----------------------------

.. automodule:: ipecharts.option.media
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.option module
------------------------------

.. automodule:: ipecharts.option.option
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.parallel module
--------------------------------

.. automodule:: ipecharts.option.parallel
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.parallelaxis module
------------------------------------

.. automodule:: ipecharts.option.parallelaxis
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.polar module
-----------------------------

.. automodule:: ipecharts.option.polar
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.radar module
-----------------------------

.. automodule:: ipecharts.option.radar
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.radiusaxis module
----------------------------------

.. automodule:: ipecharts.option.radiusaxis
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.series module
------------------------------

.. automodule:: ipecharts.option.series
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.singleaxis module
----------------------------------

.. automodule:: ipecharts.option.singleaxis
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.stateanimation module
--------------------------------------

.. automodule:: ipecharts.option.stateanimation
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.textstyle module
---------------------------------

.. automodule:: ipecharts.option.textstyle
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.timeline module
--------------------------------

.. automodule:: ipecharts.option.timeline
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.title module
-----------------------------

.. automodule:: ipecharts.option.title
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.toolbox module
-------------------------------

.. automodule:: ipecharts.option.toolbox
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.tooltip module
-------------------------------

.. automodule:: ipecharts.option.tooltip
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.visualmap module
---------------------------------

.. automodule:: ipecharts.option.visualmap
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.xaxis module
-----------------------------

.. automodule:: ipecharts.option.xaxis
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.xaxis3d module
-------------------------------

.. automodule:: ipecharts.option.xaxis3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.yaxis module
-----------------------------

.. automodule:: ipecharts.option.yaxis
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.yaxis3d module
-------------------------------

.. automodule:: ipecharts.option.yaxis3d
   :members:
   :undoc-members:
   :show-inheritance:

ipecharts.option.zaxis3d module
-------------------------------

.. automodule:: ipecharts.option.zaxis3d
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ipecharts.option
   :members:
   :undoc-members:
   :show-inheritance:
